@@ -5,8 +5,8 @@
 __author__ = "Sorin Sbarnea"
 __copyright__ = "Copyright 2010-2013, Sorin Sbarnea"
 __email__ = "sorin(dot)sbarnea(at)gmail.com"
-__status__ = "Development"
-__version__ = "0.0.21"
+__status__ = "Production"
+from version import __version__, __date__
 __date__ = "2013-03-22"
 
 __all__ = ['tee', 'colorer', 'unicode', 'execfile2', 'singleton', 'ansiterm']
